@@ -18,7 +18,7 @@
 ** along with this program; if not, see <http://www.gnu.org/licenses/>. **
 *************************************************************************/
 
-#include <algorithm>
+#include "algorithm.hpp"
 #include "BgColorSpecialHandler.hpp"
 #include "ColorSpecialHandler.hpp"
 #include "SpecialActions.hpp"
@@ -31,8 +31,8 @@ using namespace std;
  *  not all but only selected DVI pages are converted. */
 void BgColorSpecialHandler::preprocess (const string&, std::istream &is, SpecialActions &actions) {
 	Color color = ColorSpecialHandler::readColor(is);
-	unsigned pageno = actions.getCurrentPageNumber();
 	if (_pageColors.empty() || _pageColors.back().second != color) {
+		unsigned pageno = actions.getCurrentPageNumber();
 		if (!_pageColors.empty() && _pageColors.back().first == pageno)
 			_pageColors.back().second = color;
 		else
@@ -54,7 +54,7 @@ void BgColorSpecialHandler::dviBeginPage (unsigned pageno, SpecialActions &actio
 	if (_pageColors.empty())
 		return;
 	// find number of page with bg color change not lower than the current one
-	auto it = lower_bound(_pageColors.begin(), _pageColors.end(), PageColor(pageno, Color::BLACK));
+	auto it = algo::lower_bound(_pageColors, PageColor(pageno, Color::BLACK));
 	if (it != _pageColors.end() && it->first == pageno)
 		actions.setBgColor(it->second);
 	else if (it != _pageColors.begin())
