@@ -339,6 +339,7 @@ string InputReader::getString () {
  *  @return the string read */
 string InputReader::getString (size_t n) {
 	string ret;
+	ret.reserve(n);
 	while (n-- > 0)
 		ret += char(get());
 	return ret;
@@ -371,11 +372,11 @@ string InputReader::getLine () {
 
 /** Parses a sequence of key-value pairs of the form KEY=VALUE or KEY="VALUE".
  *  If parameter 'requireValues' is false, attributes may also consist of a key only.
- *  @param[out] attr the scanned attributes
  *  @param[in] requireValues true if all attributes require a value
  *  @param[in] quotechars recognized quote characters used to enclose the attribute values
- *  @return number of attributes scanned */
-int InputReader::parseAttributes (map<string,string> &attr, bool requireValues, const char *quotechars) {
+ *  @return the scanned attributes  */
+map<string,string> InputReader::parseAttributes (bool requireValues, const char *quotechars) {
+	map<string,string> attribs;
 	while (!eof()) {
 		string key;
 		skipSpace();
@@ -389,12 +390,24 @@ int InputReader::parseAttributes (map<string,string> &attr, bool requireValues,
 			get();
 			skipSpace();
 			string val = getQuotedString(quotechars);
-			attr.emplace(std::move(key), std::move(val));
+			attribs.emplace(std::move(key), std::move(val));
 		}
 		else if (!requireValues)
-			attr.emplace(std::move(key), "");
+			attribs.emplace(std::move(key), "");
 	}
-	return int(attr.size());
+	return attribs;
+}
+
+
+/** Parses a sequence of key-value pairs of the form KEY=VALUE or KEY="VALUE".
+ *  If parameter 'requireValues' is false, attributes may also consist of a key only.
+ *  @param[out] attribs the scanned attributes
+ *  @param[in] requireValues true if all attributes require a value
+ *  @param[in] quotechars recognized quote characters used to enclose the attribute values
+ *  @return number of attributes scanned */
+int InputReader::parseAttributes (map<string,string> &attribs, bool requireValues, const char *quotechars) {
+	attribs = parseAttributes(requireValues, quotechars);
+	return int(attribs.size());
 }
 
 //////////////////////////////////////////
@@ -424,4 +437,4 @@ streamsize BufferInputReader::read (char *buf, streamsize size) {
 	while (c >= 0 && size-- > 0)
 		*p++ = char(c);
 	return p-buf;
-}
\ No newline at end of file
+}
