@@ -35,6 +35,21 @@ PDFToSVG::PDFToSVG (const string &fname, SVGOutputBase &out) : ImageToSVG(fname,
 	}
 	if (!_useGS)
 		_pdfHandler.assignSVGTree(_svg);
+
+	ifstream ifs(filename());
+	if (ifs) {
+		string buf(5, 0);
+		ifs.read(&buf[0], 5);
+		if (buf == "%PDF-") {
+			int major=0, minor=0;
+			ifs >> major;
+			if (ifs.get() == '.')
+				ifs >> minor;
+			else
+				major = 0;  // missing dot => invalid PDF version
+			_pdfVersion = major*100 + minor;
+		}
+	}
 }
 
 
@@ -46,7 +61,7 @@ void PDFToSVG::checkGSAndFileFormat () {
 			if (gsVersion() > 0) {
 				ostringstream oss;
 				oss << "To process PDF files, either Ghostscript < 10.01.0 or mutool is required.\n";
-				oss << "The installed Ghostscript version " << Ghostscript().revisionstr() << " isn't supported.\n";
+				oss << "The installed Ghostscript version " << Ghostscript().revisionstr() << " is not supported.\n";
 				throw MessageException(oss.str());
 			}
 		}
@@ -71,13 +86,7 @@ int PDFToSVG::totalPageCount () const {
 
 
 bool PDFToSVG::imageIsValid () const {
-	ifstream ifs(filename());
-	if (ifs) {
-		char buf[16];
-		ifs.getline(buf, 16);
-		return std::strncmp(buf, "%PDF-1.", 7) == 0;
-	}
-	return false;
+	return _pdfVersion > 0;
 }
 
 
@@ -92,4 +101,4 @@ void PDFToSVG::convert (int pageno) {
 		embed(_pdfHandler.bbox());
 		writeSVG(pageno);
 	}
-}
\ No newline at end of file
+}
