@@ -185,11 +185,7 @@ XMLElement* XMLParser::openElement (const string &tag) {
 	string name = ir.getString("/ \t\n\r");
 	ir.skipSpace();
 	unique_ptr<XMLElement> elemNode{createElementPtr(name)};
-	map<string, string> attribs;
-	if (ir.parseAttributes(attribs, true, "\"'")) {
-		for (const auto &attrpair : attribs)
-			elemNode->addAttribute(attrpair.first, attrpair.second);
-	}
+	elemNode->addAttributes(ir.parseAttributes(true, "\"'"));
 	ir.skipSpace();
 	XMLElement *elemPtr = elemNode.get();
 	if (ir.peek() == '/')       // end of empty element tag
